@@ -27,7 +27,7 @@ class TestAws_pcluster_bootstrap_helpers(unittest.TestCase):
         runner = CliRunner()
         result = runner.invoke(cli.main)
         assert result.exit_code == 0
-        assert 'aws_pcluster_bootstrap_helpers.cli.main' in result.output
-        help_result = runner.invoke(cli.main, ['--help'])
+        assert "aws_pcluster_bootstrap_helpers.cli.main" in result.output
+        help_result = runner.invoke(cli.main, ["--help"])
         assert help_result.exit_code == 0
-        assert '--help  Show this message and exit.' in help_result.output
+        assert "--help  Show this message and exit." in help_result.output
